==> vnpy_mini-1.6.0.0.tar.gz: vnpy_mini-1.6.0.0/vnpy_mini/api/generator/mini_td_header_function.h <==
int reqAuthenticate(const dict &req, int reqid);

int reqUserLogin(const dict &req, int reqid);

int reqUserLoginEncrypt(const dict &req, int reqid);

int reqUserLogout(const dict &req, int reqid);

int reqOrderInsert(const dict &req, int reqid);

int reqOrderAction(const dict &req, int reqid);

int reqExecOrderInsert(const dict &req, int reqid);

int reqExecOrderAction(const dict &req, int reqid);

int reqForQuoteInsert(const dict &req, int reqid);

int reqQuoteInsert(const dict &req, int reqid);

int reqQuoteAction(const dict &req, int reqid);

int reqBatchOrderAction(const dict &req, int reqid);

int reqOptionSelfCloseInsert(const dict &req, int reqid);

int reqOptionSelfCloseAction(const dict &req, int reqid);

int reqCombActionInsert(const dict &req, int reqid);

int reqQryOrder(const dict &req, int reqid);

int reqQryTrade(const dict &req, int reqid);

int reqQryInvestorPosition(const dict &req, int reqid);

int reqQryTradingAccount(const dict &req, int reqid);

int reqQryInvestor(const dict &req, int reqid);

int reqQryTradingCode(const dict &req, int reqid);

int reqQryInstrumentMarginRate(const dict &req, int reqid);

int reqQryInstrumentCommissionRate(const dict &req, int reqid);

int reqQryExchange(const dict &req, int reqid);

int reqQryProduct(const dict &req, int reqid);

int reqQryInstrument(const dict &req, int reqid);

int reqQryCombInstrument(const dict &req, int reqid);

int reqQryInvestorPositionForComb(const dict &req, int reqid);

int reqQryCombAction(const dict &req, int reqid);

int reqQryDepthMarketData(const dict &req, int reqid);

int reqQryOptionSelfClose(const dict &req, int reqid);

int reqQryInstrumentStatus(const dict &req, int reqid);

int reqQryInvestorPositionDetail(const dict &req, int reqid);

int reqQryInvestorPositionCombineDetail(const dict &req, int reqid);

int reqQryExchangeMarginRate(const dict &req, int reqid);

int reqQryExchangeMarginRateAdjust(const dict &req, int reqid);

int reqQryOptionInstrTradeCost(const dict &req, int reqid);

int reqQryOptionInstrCommRate(const dict &req, int reqid);

int reqQryExecOrder(const dict &req, int reqid);

int reqQryForQuote(const dict &req, int reqid);

int reqQryQuote(const dict &req, int reqid);

int reqQryInstrumentOrderCommRate(const dict &req, int reqid);

int reqQryForQuoteParam(const dict &req, int reqid);

==> vnpy_mini-1.6.3.1.tar.gz: vnpy_mini-1.6.3.1/vnpy_mini/api/generator/mini_td_header_function.h <==
int reqAuthenticate(const dict &req, int reqid);

int reqUserLogin(const dict &req, int reqid);

int reqUserLoginEncrypt(const dict &req, int reqid);

int reqUserLogout(const dict &req, int reqid);

int reqOrderInsert(const dict &req, int reqid);

int reqOrderAction(const dict &req, int reqid);

int reqMKBatchOrderAction(const dict &req, int reqid);

int reqExecOrderInsert(const dict &req, int reqid);

int reqExecOrderAction(const dict &req, int reqid);

int reqForQuoteInsert(const dict &req, int reqid);

int reqQuoteInsert(const dict &req, int reqid);

int reqQuoteAction(const dict &req, int reqid);

int reqBatchOrderAction(const dict &req, int reqid);

int reqOptionSelfCloseInsert(const dict &req, int reqid);

int reqOptionSelfCloseAction(const dict &req, int reqid);

int reqCombActionInsert(const dict &req, int reqid);

int reqQryOrder(const dict &req, int reqid);

int reqQryTrade(const dict &req, int reqid);

int reqQryInvestorPosition(const dict &req, int reqid);

int reqQryTradingAccount(const dict &req, int reqid);

int reqQryInvestor(const dict &req, int reqid);

int reqQryTradingCode(const dict &req, int reqid);

int reqQryInstrumentMarginRate(const dict &req, int reqid);

int reqQryInstrumentCommissionRate(const dict &req, int reqid);

int reqQryExchange(const dict &req, int reqid);

int reqQryProduct(const dict &req, int reqid);

int reqQryInstrument(const dict &req, int reqid);

int reqQryCombInstrument(const dict &req, int reqid);

int reqQryInvestorPositionForComb(const dict &req, int reqid);

int reqQryCombAction(const dict &req, int reqid);

int reqQryDepthMarketData(const dict &req, int reqid);

int reqQryOptionSelfClose(const dict &req, int reqid);

int reqQryInstrumentStatus(const dict &req, int reqid);

int reqQryInvestorPositionDetail(const dict &req, int reqid);

int reqQryExchangeMarginRate(const dict &req, int reqid);

int reqQryExchangeMarginRateAdjust(const dict &req, int reqid);

int reqQryOptionInstrTradeCost(const dict &req, int reqid);

int reqQryOptionInstrCommRate(const dict &req, int reqid);

int reqQryExecOrder(const dict &req, int reqid);

int reqQryForQuote(const dict &req, int reqid);

int reqQryQuote(const dict &req, int reqid);

int reqQryInstrumentOrderCommRate(const dict &req, int reqid);

int reqQryForQuoteParam(const dict &req, int reqid);

int reqQryTraderOffer(const dict &req, int reqid);

int reqQryInvestorProdSPBMDetail(const dict &req, int reqid);
